@@ -1,22 +1,13 @@
-from graphql import OperationType
 from pydantic import Field
 from rath import rath
 import contextvars
-import logging
 
-from rath.links.base import TerminatingLink
-from rath.contrib.fakts.links.aiohttp import FaktsAIOHttpLink
-from rath.contrib.fakts.links.websocket import FaktsWebsocketLink
-from rath.contrib.herre.links.auth import HerreAuthLink
-from rath.links.aiohttp import AIOHttpLink
 from rath.links.auth import AuthTokenLink
 
-from rath.links.base import TerminatingLink
-from rath.links.compose import TypedComposedLink, compose
+from rath.links.compose import TypedComposedLink
 from rath.links.dictinglink import DictingLink
 from rath.links.shrink import ShrinkingLink
 from rath.links.split import SplitLink
-from rath.links.websockets import WebSocketLink
 
 current_fluss_rath = contextvars.ContextVar("current_fluss_rath")
 
@@ -29,7 +20,7 @@ class FlussLinkComposition(TypedComposedLink):
 
 
 class FlussRath(rath.Rath):
-    """_summary_
+    """Fluss Rath
 
     Args:
         rath (_type_): _description_
