@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Union, Any, Tuple
 
 
 class NodeException(str):
@@ -15,7 +15,7 @@ class NodeException(str):
             v = str(v)
 
         if not isinstance(v, str):
-            raise TypeError("Dataframe required")
+            raise TypeError(f"Could not parse Exception {v} as a string")
         # you could also return a string here which would mean model.post_code
         # would be a string, pydantic won't care but you could end up with some
         # confusion since the value's type won't match the type annotation
@@ -26,4 +26,4 @@ class NodeException(str):
         return f"Exception({self.value})"
 
 
-EventValue = Union[List[str], NodeException]
+EventValue = Union[Tuple[Any], NodeException]
